import type { PropsWithChildren } from 'react';
import type { ViewProps } from 'react-native';
import type { AnimatedProps } from 'react-native-reanimated';
type AnimatedComponentProps = PropsWithChildren<AnimatedProps<ViewProps>>;
declare function Provider({ children, isOpen: initialIsOpen, onChange, style, ...rest }: {
    children: React.ReactNode;
    isOpen?: boolean;
    onChange?: (value: boolean) => void;
} & AnimatedProps<ViewProps>): import("react/jsx-runtime").JSX.Element;
declare function Header({ children }: {
    children: React.ReactNode;
}): import("react/jsx-runtime").JSX.Element;
declare function Icon({ children, rotation, }: {
    children: React.ReactNode;
    rotation?: 'clockwise' | 'counter-clockwise';
}): import("react/jsx-runtime").JSX.Element;
declare function Expanded({ children, ...rest }: AnimatedComponentProps): import("react/jsx-runtime").JSX.Element | undefined;
declare function Collapsed({ children, ...rest }: AnimatedComponentProps): import("react/jsx-runtime").JSX.Element | undefined;
declare function Always({ children, ...rest }: AnimatedComponentProps): import("react/jsx-runtime").JSX.Element;
declare function Sibling({ children, ...rest }: AnimatedComponentProps): import("react/jsx-runtime").JSX.Element;
export declare const Accordion: {
    /**
     * The main component that will handle the state of the accordion.
     *
     * @param isOpen boolean
     * @param onChange (value: boolean) => void
     */
    Accordion: typeof Provider;
    /**
     * The header of the accordion.
     */
    Header: typeof Header;
    /**
     * The component that will wrap any children and it will apply a rotation to it.
     *
     * @param children
     * @param rotation clockwise | counter-clockwise
     */
    HeaderIcon: typeof Icon;
    /**
     * This is the content that will be displayed when the accordion is open
     */
    Expanded: typeof Expanded;
    /**
     * This is the content that will be displayed when the accordion is closed
     */
    Collapsed: typeof Collapsed;
    /**
     * This is the content that will always be displayed
     */
    Always: typeof Always;
    /**
     *
     * This is a component that will add the layout transition to any
     * sibling components. Useful when you are rendering other components
     * that are not direct children of the Accordion component.
     */
    Sibling: typeof Sibling;
};
export {};
//# sourceMappingURL=index.d.ts.map